==> tekton-model-triggers-v1alpha1-6.6.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/ClusterInterceptorFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterInterceptorFluentImpl<A extends ClusterInterceptorFluent<A>> extends BaseFluent<A> implements ClusterInterceptorFluent<A>{
  public ClusterInterceptorFluentImpl() {
  }
  public ClusterInterceptorFluentImpl(ClusterInterceptor instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ClusterInterceptorSpecBuilder spec;
  private ClusterInterceptorStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ClusterInterceptorFluent.MetadataNested<A> withNewMetadata() {
    return new ClusterInterceptorFluentImpl.MetadataNestedImpl();
  }
  public ClusterInterceptorFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ClusterInterceptorFluentImpl.MetadataNestedImpl(item);
  }
  public ClusterInterceptorFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ClusterInterceptorFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ClusterInterceptorFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterInterceptorSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ClusterInterceptorSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ClusterInterceptorSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ClusterInterceptorSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ClusterInterceptorFluent.SpecNested<A> withNewSpec() {
    return new ClusterInterceptorFluentImpl.SpecNestedImpl();
  }
  public ClusterInterceptorFluent.SpecNested<A> withNewSpecLike(ClusterInterceptorSpec item) {
    return new ClusterInterceptorFluentImpl.SpecNestedImpl(item);
  }
  public ClusterInterceptorFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ClusterInterceptorFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ClusterInterceptorSpecBuilder().build());
  }
  public ClusterInterceptorFluent.SpecNested<A> editOrNewSpecLike(ClusterInterceptorSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterInterceptorStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ClusterInterceptorStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ClusterInterceptorStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ClusterInterceptorStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public ClusterInterceptorFluent.StatusNested<A> withNewStatus() {
    return new ClusterInterceptorFluentImpl.StatusNestedImpl();
  }
  public ClusterInterceptorFluent.StatusNested<A> withNewStatusLike(ClusterInterceptorStatus item) {
    return new ClusterInterceptorFluentImpl.StatusNestedImpl(item);
  }
  public ClusterInterceptorFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ClusterInterceptorFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ClusterInterceptorStatusBuilder().build());
  }
  public ClusterInterceptorFluent.StatusNested<A> editOrNewStatusLike(ClusterInterceptorStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClusterInterceptorFluentImpl that = (ClusterInterceptorFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ClusterInterceptorFluent.MetadataNested<N>> implements ClusterInterceptorFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ClusterInterceptorFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ClusterInterceptorSpecFluentImpl<ClusterInterceptorFluent.SpecNested<N>> implements ClusterInterceptorFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ClusterInterceptorSpec item) {
      this.builder = new ClusterInterceptorSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ClusterInterceptorSpecBuilder(this);
    }
    ClusterInterceptorSpecBuilder builder;
    public N and() {
      return (N) ClusterInterceptorFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ClusterInterceptorStatusFluentImpl<ClusterInterceptorFluent.StatusNested<N>> implements ClusterInterceptorFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ClusterInterceptorStatus item) {
      this.builder = new ClusterInterceptorStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ClusterInterceptorStatusBuilder(this);
    }
    ClusterInterceptorStatusBuilder builder;
    public N and() {
      return (N) ClusterInterceptorFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/ClusterInterceptorFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterInterceptorFluentImpl<A extends ClusterInterceptorFluent<A>> extends BaseFluent<A> implements ClusterInterceptorFluent<A>{
  public ClusterInterceptorFluentImpl() {
  }
  public ClusterInterceptorFluentImpl(ClusterInterceptor instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ClusterInterceptorSpecBuilder spec;
  private ClusterInterceptorStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ClusterInterceptorFluentImpl.MetadataNested<A> withNewMetadata() {
    return new ClusterInterceptorFluentImpl.MetadataNestedImpl();
  }
  public ClusterInterceptorFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ClusterInterceptorFluentImpl.MetadataNestedImpl(item);
  }
  public ClusterInterceptorFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ClusterInterceptorFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ClusterInterceptorFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterInterceptorSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ClusterInterceptorSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ClusterInterceptorSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ClusterInterceptorSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ClusterInterceptorFluentImpl.SpecNested<A> withNewSpec() {
    return new ClusterInterceptorFluentImpl.SpecNestedImpl();
  }
  public ClusterInterceptorFluentImpl.SpecNested<A> withNewSpecLike(ClusterInterceptorSpec item) {
    return new ClusterInterceptorFluentImpl.SpecNestedImpl(item);
  }
  public ClusterInterceptorFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ClusterInterceptorFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ClusterInterceptorSpecBuilder().build());
  }
  public ClusterInterceptorFluentImpl.SpecNested<A> editOrNewSpecLike(ClusterInterceptorSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterInterceptorStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ClusterInterceptorStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ClusterInterceptorStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ClusterInterceptorStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public ClusterInterceptorFluentImpl.StatusNested<A> withNewStatus() {
    return new ClusterInterceptorFluentImpl.StatusNestedImpl();
  }
  public ClusterInterceptorFluentImpl.StatusNested<A> withNewStatusLike(ClusterInterceptorStatus item) {
    return new ClusterInterceptorFluentImpl.StatusNestedImpl(item);
  }
  public ClusterInterceptorFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ClusterInterceptorFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ClusterInterceptorStatusBuilder().build());
  }
  public ClusterInterceptorFluentImpl.StatusNested<A> editOrNewStatusLike(ClusterInterceptorStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterInterceptorFluentImpl that = (ClusterInterceptorFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ClusterInterceptorFluentImpl.MetadataNested<N>> implements ClusterInterceptorFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ClusterInterceptorFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ClusterInterceptorSpecFluentImpl<ClusterInterceptorFluentImpl.SpecNested<N>> implements ClusterInterceptorFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ClusterInterceptorSpec item) {
      this.builder = new ClusterInterceptorSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ClusterInterceptorSpecBuilder(this);
    }
    ClusterInterceptorSpecBuilder builder;
    public N and() {
      return (N) ClusterInterceptorFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ClusterInterceptorStatusFluentImpl<ClusterInterceptorFluentImpl.StatusNested<N>> implements ClusterInterceptorFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ClusterInterceptorStatus item) {
      this.builder = new ClusterInterceptorStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ClusterInterceptorStatusBuilder(this);
    }
    ClusterInterceptorStatusBuilder builder;
    public N and() {
      return (N) ClusterInterceptorFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
